| Safe Haskell | Safe-Inferred |
|---|---|
| Language | GHC2021 |
Fold.ShortcutNonempty.Type
Synopsis
- data ShortcutNonemptyFold a b = forall x y.ShortcutNonemptyFold {}
- data Will
- data Vitality a b
Documentation
data ShortcutNonemptyFold a b Source #
Processes at least one input of type a, has the ability to halt
midway through the stream, and results in a value of type b
Constructors
| forall x y. ShortcutNonemptyFold | |
Instances
Constructors
| Ambivalent | |
| Tenacious |